@@ -26,6 +26,11 @@
 #include "../liblxqt-config-cursor/selectwnd.h"
 #include "keyboardlayoutconfig.h"
 
+#ifdef WITH_TOUCHPAD
+#include "touchpadconfig.h"
+#include "touchpaddevice.h"
+#endif
+
 int main(int argc, char** argv) {
     LXQt::SingleApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
@@ -39,6 +44,11 @@ int main(int argc, char** argv) {
     app.setApplicationVersion(VERINFO);
 
     dlgOptions.setCommandLine(&parser);
+#ifdef WITH_TOUCHPAD
+    QCommandLineOption loadOption("load-touchpad",
+            app.tr("Load last touchpad settings."));
+    parser.addOption(loadOption);
+#endif
     parser.addVersionOption();
     parser.addHelpOption();
     parser.process(app);
@@ -48,6 +58,15 @@ int main(int argc, char** argv) {
     if(configName.isEmpty())
       configName = "session";
     LXQt::Settings settings(configName);
+
+#ifdef WITH_TOUCHPAD
+    bool loadLastTouchpadSettings = parser.isSet(loadOption);
+    if (loadLastTouchpadSettings) {
+        TouchpadDevice::loadSettings(&settings);
+        return 0;
+    }
+#endif
+
     LXQt::ConfigDialog dlg(QObject::tr("Keyboard and Mouse Settings"), &settings);
     app.setActivationWindow(&dlg);
 
@@ -68,6 +87,13 @@ int main(int argc, char** argv) {
     dlg.addPage(keyboardLayoutConfig, QObject::tr("Keyboard Layout"), "input-keyboard");
     QObject::connect(&dlg, SIGNAL(reset()), keyboardLayoutConfig, SLOT(reset()));
 
+#ifdef WITH_TOUCHPAD
+    TouchpadConfig* touchpadConfig = new TouchpadConfig(&settings, &dlg);
+    dlg.addPage(touchpadConfig, QObject::tr("Mouse and Touchpad"), "input-tablet");
+    QObject::connect(&dlg, &LXQt::ConfigDialog::reset,
+                     touchpadConfig, &TouchpadConfig::reset);
+#endif
+
     dlg.setWindowIcon(QIcon::fromTheme("input-keyboard"));
 
     const QString initialPage = dlgOptions.page();
